(function () {
  function loadScript(src) {
    return new Promise((resolve, reject) => {
      const script = document.createElement("script");
      script.src = src;
      script.onload = resolve;
      script.onerror = reject;
      document.head.appendChild(script);
    });
  }

  // Function to load multiple Google Font URLs
  function loadFonts(fontUrls) {
    return Promise.all(
      fontUrls.map((url) => {
        return new Promise((resolve, reject) => {
          const link = document.createElement("link");
          link.href = url;
          link.rel = "stylesheet";
          link.onload = resolve;
          link.onerror = reject;
          document.head.appendChild(link);
        });
      }),
    );
  }

  // Load React, ReactDOM, and then load fonts and the web component
  Promise.all([
    loadScript(
      "https://cdn.jsdelivr.net/npm/react@18/umd/react.production.min.js",
    ),
    loadScript(
      "https://cdn.jsdelivr.net/npm/react-dom@18/umd/react-dom.production.min.js",
    ),
  ])
    .then(() => {
      // Array of multiple font URLs
      const fontUrls = [
        "https://fonts.googleapis.com/css2?family=Roboto:wght@400;700&display=swap",
        "https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&display=swap",
        "https://fonts.googleapis.com/css2?family=Open+Sans:wght@400;700&display=swap",
        "https://fonts.cdnfonts.com/css/poppins",
        "https://fonts.cdnfonts.com/css/inter",
      ];

      // Load all font URLs and the component script in parallel
      return Promise.all([
        loadFonts(fontUrls),
        loadScript(
          "https://cdn.jsdelivr.net/npm/issueiq@0.2.3/dist/issueiq-bubble.umd.js",
        ),
      ]);
    })
    .catch(console.error);
})();
